@@ -311,6 +311,8 @@ case "modifica":  				$messaggio = "modify"; break;
 case "In modo predefinito importa":  		$messaggio = "By default import"; break;
 case "i prezzi di alcuni periodi <em>non sono stati inseriti</em> perchè importati da altre tariffe":	$messaggio = "the prices of some periods <em>have not been inserted</em> because they are imported from other rates"; break;
 case "limite non considerato per le persone aggiuntive nelle interconnessioni":	$messaggio = "limit not considered for additional people in interconnections"; break;
+case "Seleziona adesso questo costo anche per tutti gli utenti che non hanno privilegi per usare tutti i costi":	$messaggio = "Select now this cost also for all the users that don't have privileges to use all the costs"; break;
+case "Aggiungi adesso questo costo a tutte le pagine create per il sito web":	$messaggio = "Add now this cost to all existing website pages"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
