@@ -15,6 +15,7 @@ case "Modifica i dati del cliente":  			$messaggio = "Modifiez les données du c
 case "La prenotazione è dell'anno precedente, si potrà modificare solo la data finale":	$messaggio = "La réservation est de l'an précédent, on pourra modifier seulement la date finale"; break;
 case "settimane":  								$messaggio = "semaines"; break;
 case "giorni":  								$messaggio = "jours"; break;
+case "giorno":  				$messaggio = "day"; break;
 case "dal":  									$messaggio = "de"; break;
 case "al":  									$messaggio = "à"; break;
 case "cambia in":  								$messaggio = "changez en"; break;
@@ -252,6 +253,8 @@ case "La <b>tariffa</b> richiesta è <span class=\"colred\">chiusa</span> in que
 case "cambia il commento":  			$messaggio = "change comment"; break;
 case "Il commento":  				$messaggio = "Comment"; break;
 case "verrà cambiato":  			$messaggio = "will be changed"; break;
+case "per ":  					$messaggio = "for "; break;
+case "Il numero di":  				$messaggio = "The number of"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
