@@ -403,6 +403,27 @@ case "La tariffa":  				$messaggio = "Rate"; break;
 case "è ancora in uso nelle interconnessioni":	$messaggio = "is still in use in interconnections"; break;
 case "almeno 8 caratteri, con lettere e numeri o simboli":	$messaggio = "at least 8 characters, with letters and numbers or symbols"; break;
 case "diversa dalle ultime":  			$messaggio = "different from last"; break;
+case "Condizioni Generali di Contratto":  	$messaggio = "General Terms and Conditions"; break;
+case "del servizio di memorizzazione delle carte di credito":	$messaggio = "of the credit cards storage service"; break;
+case "La password non è stata modificata":  	$messaggio = "The password has not been modified"; break;
+case "password errata":  			$messaggio = "wrong password"; break;
+case "adulto":  				$messaggio = "adult"; break;
+case "adulti":  				$messaggio = "adults"; break;
+case "bambino":  				$messaggio = "child"; break;
+case "bambini":  				$messaggio = "children"; break;
+case "Numero di tipologie di persone":  	$messaggio = "Number of people types"; break;
+case "Tipologia":  				$messaggio = "Type"; break;
+case "Può essere ospite principale":  		$messaggio = "Can be main guest"; break;
+case "Prezzo in percentuale del prezzo per persona":	$messaggio = "Price in percentage of per person price"; break;
+case "arrotondato a":  				$messaggio = "rounded to"; break;
+case "Modifica le tipologie di persone":  	$messaggio = "Modify people types"; break;
+case "Il numero di tipologie di persone è sbagliato":	$messaggio = "The number of people types is wrong"; break;
+case "Il numero di tipologie di persone è stato cambiato":	$messaggio = "The number of people types has been changed"; break;
+case "I dati inseriti non sono corretti":  	$messaggio = "Inserted data are incorrect"; break;
+case "Le tipologie di persone sono state modificate":	$messaggio = "The people types have been modified"; break;
+case "Cambia per tutti gli utenti":  		$messaggio = "Change for all users"; break;
+case "Modifica le tipologie di persone per tutti gli utenti":	$messaggio = "Modify people types for all users"; break;
+case "tipi di persona":  			$messaggio = "person types"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
