@@ -349,6 +349,25 @@ case "potrà modificare i <b>documenti come API</b>":	$messaggio = "will be able
 case "Attenzione":  				$messaggio = "Warning"; break;
 case "questo può consentire l'accesso ai dati di tutte le prenotazioni":	$messaggio = "this can allow access to data of all reservations"; break;
 case "non potrà più modificare i <b>documenti come API</b>":	$messaggio = "will not be able to modify <b>documents as API</b> anymore"; break;
+case "Gestione della password per le carte di credito":	$messaggio = "Management of credit cards password"; break;
+case "potrà gestire la <b>password per le carte di credito</b>":	$messaggio = "will be able to manage the <b>credit cards password</b>"; break;
+case "non potrà più gestire la <b>password per le carte di credito</b>":	$messaggio = "will not be able to manage the <b>credit cards password</b>"; break;
+case "senza mostrare il valore":  		$messaggio = "without showing the value"; break;
+case "mostrando il valore":  			$messaggio = "showing the value"; break;
+case "senza mostrare i valori":  		$messaggio = "without showing the values"; break;
+case "mostrando i valori":  			$messaggio = "showing the values"; break;
+case "Possibilità di modificare l'utente che ha inserito":	$messaggio = "Possibility to modify the inserting user"; break;
+case "con tutti gli utenti":  			$messaggio = "with all users"; break;
+case "solo con utenti dei suoi gruppi":  	$messaggio = "only with users from his groups"; break;
+case "mostrando l'utente":  			$messaggio = "showing the user"; break;
+case "senza mostrare l'utente":  		$messaggio = "without showing the user"; break;
+case "potrà modificare l'<b>utente</b> che ha inserito la prenotazione nel":	$messaggio = "will be able to modify the <b>user</b> that inserted the reservation in"; break;
+case "non potrà modificare l'<b>utente</b> che ha inserito la prenotazione nel":	$messaggio = "will not be able to modify the <b>user</b> that inserted the reservation in"; break;
+case "senza mostrarla":  			$messaggio = "without showing it"; break;
+case "senza mostrarli":  			$messaggio = "without showing them"; break;
+case "Modifica delle tipologie di persone":  	$messaggio = "Modify people types"; break;
+case "potrà modificare le sue <b>tipologie di persone</b>":	$messaggio = "will be able to modify his <b>people types</b>"; break;
+case "non potrà più modificare le sue <b>tipologie di persone</b>":	$messaggio = "will not be able to modify his <b>people types</b>"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
