@@ -20,6 +20,16 @@ case "aggiornata":  				$messaggio = "mise à jour"; break;
 case "commento":  				$messaggio = "commentaire"; break;
 case "commento della foto":  			$messaggio = "commentaire de la photo"; break;
 case "aggiornato":  				$messaggio = "mis à jour"; break;
+case "disponibilità":  				$messaggio = "availability"; break;
+case "permanenza min.":  			$messaggio = "minimum stay"; break;
+case "permanenza mass.":  			$messaggio = "maximum stay"; break;
+case "mostra disponibilità":  			$messaggio = "show availability"; break;
+case "mostra permanenza minima":  		$messaggio = "show minimum stay"; break;
+case "raggruppa le date":  			$messaggio = "group dates"; break;
+case "in modo predefinito per la tariffa":  	$messaggio = "by default for rate"; break;
+case "Numero di persone predefinito per la tariffa":	$messaggio = "Default number of people for rate"; break;
+case "Modifica i valori":  			$messaggio = "Modify values"; break;
+case "non definito":  				$messaggio = "undefined"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
